import torch
from transformers import WhisperProcessor, WhisperForConditionalGeneration
import librosa

device = "mps" if torch.backends.mps.is_available() else "cpu"  # Используем MPS, если доступно
print(f"Using device: {device}")

# Загружаем аудиофайл
speech, _ = librosa.load("stt/test2.ogg")

# Загружаем модель и процессор
processor = WhisperProcessor.from_pretrained("openai/whisper-small")
model = WhisperForConditionalGeneration.from_pretrained("openai/whisper-small").to(device)

# Настройки для английского языка
model.config.forced_decoder_ids = processor.get_decoder_prompt_ids(language="ru", task="transcribe")

# Подготовка входных данных
input_features = processor(speech, return_tensors="pt").input_features.to(device)

# Генерация текста
predicted_ids = model.generate(input_features)
transcription = processor.batch_decode(predicted_ids, skip_special_tokens=True)

print(transcription)